@@ -790,3 +790,9 @@ class VariableClConsoleArgs(Variable):
     """
     type = "list"
     value = []
+
+class VariableClClientType(ReadonlyVariable):
+    """
+    Тип клиента получающего информацию от core
+    """
+    value = ""
